# SwarmPAL

---
[![Swarm-VRE](https://img.shields.io/badge/%F0%9F%9A%80%20launch-Swarm--VRE-blue)](https://vre.vires.services/hub/user-redirect/git-pull?repo=https%3A%2F%2Fgithub.com%2Fsmithara%2Fswarmpal-demo&urlpath=lab%2Ftree%2Fswarmpal-demo%2FREADME.ipynb&branch=main)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/smithara/swarmpal-demo/HEAD)

[![PyPI](https://img.shields.io/pypi/v/swarmpal)]( https://pypi.org/project/swarmpal/)
[![Documentation](https://img.shields.io/badge/docs-online-success)][rtd-link]
[![GitHub Discussion][github-discussions-badge]][github-discussions-link]

[![Actions Status][actions-badge]][actions-link]
[![Code style: black][black-badge]][black-link]
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

---

[actions-badge]:            https://github.com/Swarm-DISC/SwarmPAL/workflows/CI/badge.svg
[actions-link]:             https://github.com/Swarm-DISC/SwarmPAL/actions
[black-badge]:              https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]:               https://github.com/psf/black
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/swarmpal
[conda-link]:               https://github.com/conda-forge/swarmpal-feedstock
[contribute-badge]:         https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg
[contribute-link]:          CODE_OF_CONDUCT.md
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/Swarm-DISC/SwarmPAL/discussions
[pypi-link]:                https://pypi.org/project/swarmpal/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/swarmpal
[pypi-version]:             https://badge.fury.io/py/swarmpal.svg
[rtd-badge]:                https://img.shields.io/badge/docs-online-success
[rtd-link]:                 https://swarmpal.readthedocs.io/

![SwarmPAL diagram](https://swarmpal-benchmarks.netlify.app/swarmpal-diagram.png)

For more information see:
- <https://swarmdisc.org/lab/>
